@@ -47,6 +47,8 @@ class GetCrmIntegralHandler(TopBaseHandler):
         """
         app_id = self.get_taobao_param().source_app_id
         user_nick = self.get_taobao_param().user_nick
+        if not user_nick:
+            return self.reponse_json_error("error", "请先授权登录")
         app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
         if app_info:
             access_token = app_info.access_token
